/**
    @file ft51_spi_registers.h

    @brief SPI registers library

    Registers and bit-masks for Serial Peripheral Interface Master and Slave.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */

#ifndef __FT51_SPI_REGISTERS_H__
#define __FT51_SPI_REGISTERS_H__

//------------------------------------------------------------------------------
// Register 72 (0x48) SPI_SLAVE_CONTROL
#define SPI_SLAVE_CONTROL                     0x48

// Register 72 Bit Definitions
#define BIT_SPI_SLAVE_SOFT_RESET              0                                 // Write a 1 to reset SPI_SLAVE
#define MASK_SPI_SLAVE_SOFT_RESET             (0x1 << BIT_SPI_SLAVE_SOFT_RESET)
#define BIT_SPI_SLAVE_DEV_EN                  1                                 // Write a 1 to enable SPI_SLAVE
#define MASK_SPI_SLAVE_DEV_EN                 (0x1 << BIT_SPI_SLAVE_DEV_EN)

//------------------------------------------------------------------------------
// Register 74 (0x4A) SPI_SLAVE_TX_DATA
#define SPI_SLAVE_TX_DATA                   0x4A

// Register 74 Bit Definitions
#define BIT_SPI_SLAVE_DATA_TX_0               0                                 // SPI Slave Tx Data. Trigger will be used to indicate when new data has been written.
#define MASK_SPI_SLAVE_DATA_TX_0              (0x1 << BIT_SPI_SLAVE_DATA_TX_0)
#define BIT_SPI_SLAVE_DATA_TX_1               1                                 // SPI Slave Tx Data. Trigger will be used to indicate when new data has been written.
#define MASK_SPI_SLAVE_DATA_TX_1              (0x1 << BIT_SPI_SLAVE_DATA_TX_1)
#define BIT_SPI_SLAVE_DATA_TX_2               2                                 // SPI Slave Tx Data. Trigger will be used to indicate when new data has been written.
#define MASK_SPI_SLAVE_DATA_TX_2              (0x1 << BIT_SPI_SLAVE_DATA_TX_2)
#define BIT_SPI_SLAVE_DATA_TX_3               3                                 // SPI Slave Tx Data. Trigger will be used to indicate when new data has been written.
#define MASK_SPI_SLAVE_DATA_TX_3              (0x1 << BIT_SPI_SLAVE_DATA_TX_3)
#define BIT_SPI_SLAVE_DATA_TX_4               4                                 // SPI Slave Tx Data. Trigger will be used to indicate when new data has been written.
#define MASK_SPI_SLAVE_DATA_TX_4              (0x1 << BIT_SPI_SLAVE_DATA_TX_4)
#define BIT_SPI_SLAVE_DATA_TX_5               5                                 // SPI Slave Tx Data. Trigger will be used to indicate when new data has been written.
#define MASK_SPI_SLAVE_DATA_TX_5              (0x1 << BIT_SPI_SLAVE_DATA_TX_5)
#define BIT_SPI_SLAVE_DATA_TX_6               6                                 // SPI Slave Tx Data. Trigger will be used to indicate when new data has been written.
#define MASK_SPI_SLAVE_DATA_TX_6              (0x1 << BIT_SPI_SLAVE_DATA_TX_6)
#define BIT_SPI_SLAVE_DATA_TX_7               7                                 // SPI Slave Tx Data. Trigger will be used to indicate when new data has been written.
#define MASK_SPI_SLAVE_DATA_TX_7              (0x1 << BIT_SPI_SLAVE_DATA_TX_7)
#define MASK_SPI_SLAVE_DATA_TX                (0xFF << BIT_SPI_SLAVE_DATA_TX_0)

//------------------------------------------------------------------------------
// Register 75 (0x4B) SPI_SLAVE_RX_DATA
#define SPI_SLAVE_RX_DATA                   0x4B

// Register 75 Bit Definitions
#define BIT_SPI_SLAVE_DATA_RX_0               0                                 // SPI Slave Rx Data. Trigger will be used to indicate when data has been read out of the register.
#define MASK_SPI_SLAVE_DATA_RX_0              (0x1 << BIT_SPI_SLAVE_DATA_RX_0)
#define BIT_SPI_SLAVE_DATA_RX_1               1                                 // SPI Slave Rx Data. Trigger will be used to indicate when data has been read out of the register.
#define MASK_SPI_SLAVE_DATA_RX_1              (0x1 << BIT_SPI_SLAVE_DATA_RX_1)
#define BIT_SPI_SLAVE_DATA_RX_2               2                                 // SPI Slave Rx Data. Trigger will be used to indicate when data has been read out of the register.
#define MASK_SPI_SLAVE_DATA_RX_2              (0x1 << BIT_SPI_SLAVE_DATA_RX_2)
#define BIT_SPI_SLAVE_DATA_RX_3               3                                 // SPI Slave Rx Data. Trigger will be used to indicate when data has been read out of the register.
#define MASK_SPI_SLAVE_DATA_RX_3              (0x1 << BIT_SPI_SLAVE_DATA_RX_3)
#define BIT_SPI_SLAVE_DATA_RX_4               4                                 // SPI Slave Rx Data. Trigger will be used to indicate when data has been read out of the register.
#define MASK_SPI_SLAVE_DATA_RX_4              (0x1 << BIT_SPI_SLAVE_DATA_RX_4)
#define BIT_SPI_SLAVE_DATA_RX_5               5                                 // SPI Slave Rx Data. Trigger will be used to indicate when data has been read out of the register.
#define MASK_SPI_SLAVE_DATA_RX_5              (0x1 << BIT_SPI_SLAVE_DATA_RX_5)
#define BIT_SPI_SLAVE_DATA_RX_6               6                                 // SPI Slave Rx Data. Trigger will be used to indicate when data has been read out of the register.
#define MASK_SPI_SLAVE_DATA_RX_6              (0x1 << BIT_SPI_SLAVE_DATA_RX_6)
#define BIT_SPI_SLAVE_DATA_RX_7               7                                 // SPI Slave Rx Data. Trigger will be used to indicate when data has been read out of the register.
#define MASK_SPI_SLAVE_DATA_RX_7              (0x1 << BIT_SPI_SLAVE_DATA_RX_7)
#define MASK_SPI_SLAVE_DATA_RX                (0xFF << BIT_SPI_SLAVE_DATA_RX_0)

//------------------------------------------------------------------------------
// Register 76 (0x4C) SPI_SLAVE_IEN
#define SPI_SLAVE_IEN                  0x4C

// Register 76 Bit Definitions
#define BIT_SPI_SLAVE_HOLD_TXE_IEN            0                                 // Interrupt enable for spi_slave_hold_txe_int
#define MASK_SPI_SLAVE_HOLD_TXE_IEN           (0x1 << BIT_SPI_SLAVE_HOLD_TXE_IEN)
#define BIT_SPI_SLAVE_TX_DONE_IEN             1                                 // Interrupt enable for spi_slave_tx_done
#define MASK_SPI_SLAVE_TX_DONE_IEN            (0x1 << BIT_SPI_SLAVE_TX_DONE_IEN)
#define BIT_SPI_SLAVE_TX_OE_IEN               2                                 // Interrupt enable for spi_slave_tx_oe
#define MASK_SPI_SLAVE_TX_OE_IEN              (0x1 << BIT_SPI_SLAVE_TX_OE_IEN)
#define BIT_SPI_SLAVE_RX_FULL_IEN             3                                 // Interrupt enable for spi_slave_rx_full_int
#define MASK_SPI_SLAVE_RX_FULL_IEN            (0x1 << BIT_SPI_SLAVE_RX_FULL_IEN)
#define BIT_SPI_SLAVE_RX_OE_IEN               4                                 // Interrupt enable for spi_slave_rx_oe
#define MASK_SPI_SLAVE_RX_OE_IEN              (0x1 << BIT_SPI_SLAVE_RX_OE_IEN)

//------------------------------------------------------------------------------
// Register 77 (0x4D) SPI_SLAVE_INT
#define SPI_SLAVE_INT                      0x4D

// Register 77 Bit Definitions
#define BIT_SPI_SLAVE_HOLD_TXE_INT            0                                 // Tx holding register interrupt bit. When high it indicates that the holding register is empty.
#define MASK_SPI_SLAVE_HOLD_TXE_INT           (0x1 << BIT_SPI_SLAVE_HOLD_TXE_INT)
#define BIT_SPI_SLAVE_TX_DONE_INT             1                                 // Tx state machine interrupt bit. Set when the state machine moves from busy to idle, i.e. it will be 0 when a transaction is in progress and 1 when the shift register becomes empty.
#define MASK_SPI_SLAVE_TX_DONE_INT            (0x1 << BIT_SPI_SLAVE_TX_DONE_INT)
#define BIT_SPI_SLAVE_TX_OE_INT               2                                 // Tx overrun error. Set to 1 when data is written to spi_data_tx while the register is still full. If this occurs the old data is overwritten.
#define MASK_SPI_SLAVE_TX_OE_INT              (0x1 << BIT_SPI_SLAVE_TX_OE_INT)
#define BIT_SPI_SLAVE_RX_FULL_INT             3                                 // Rx data register interrupt bit. When high it indicates that spi_data_rx has new data to be read out.
#define MASK_SPI_SLAVE_RX_FULL_INT            (0x1 << BIT_SPI_SLAVE_RX_FULL_INT)
#define BIT_SPI_SLAVE_RX_OE_INT               4                                 // Rx overrun error. Set to 1 when data is received and spi_data_rx is still full. If this occurs the new data is discarded.
#define MASK_SPI_SLAVE_RX_OE_INT              (0x1 << BIT_SPI_SLAVE_RX_OE_INT)
#define BIT_SPI_SLAVE_TX_BUSY                 5                                 // When 1 this means that the tx state machine is busy processing a transfer.
#define MASK_SPI_SLAVE_TX_BUSY                (0x1 << BIT_SPI_SLAVE_TX_BUSY)

//------------------------------------------------------------------------------
// Register 78 (0x4E) SPI_SLAVE_SETUP
#define SPI_SLAVE_SETUP                     0x4E

// Register 78 Bit Definitions
#define BIT_SPI_CPHA                          0                                 // SPI Clock Phase Bit - selects the format of the SPI clk. A change of this bit aborts a transmission in progress and returns the SPI system into idle state. 0 - data is latched from SDI on the SPI clk leading edge and loaded onto SDO on the SPI clk trailing edge. 1 - data is latched from SDI on the SPI clk trailing edge and loaded onto SDO on the SPI clk leading edge.
#define MASK_SPI_CPHA                         (0x1 << BIT_SPI_CPHA)
#define BIT_SPI_CPOL                          1                                 // SPI Clock Polarity Bit - selects the polarity of the SPI clk. When transmitting data between SPI modules, both modules must be using the same CPOL values. A change of this bit aborts a transmission in progress and returns the SPI system into idle state. 0 - Active high clk, SCK low in idle. 1 - Active high clk, SCK high in idle.
#define MASK_SPI_CPOL                         (0x1 << BIT_SPI_CPOL)
#define BIT_SPI_LSBFIRST                      2                                 // When 1, data is transferred LSB first. When 0, data is transferred MSB first. This does not affect the order in which data is stored in the rx and tx registers, simply the order in which data is transmitted and received.
#define MASK_SPI_LSBFIRST                     (0x1 << BIT_SPI_LSBFIRST)

//------------------------------------------------------------------------------
// Register 80 (0x50) SPI_MASTER_CONTROL
#define SPI_MASTER_CONTROL                    0x50

// Register 80 Bit Definitions
#define BIT_SPI_MASTER_SOFT_RESET             0                                 // Write a 1 to reset SPI_MASTER
#define MASK_SPI_MASTER_SOFT_RESET            (0x1 << BIT_SPI_MASTER_SOFT_RESET)
#define BIT_SPI_MASTER_DEV_EN                 1                                 // Write a 1 to enable SPI_MASTER
#define MASK_SPI_MASTER_DEV_EN                (0x1 << BIT_SPI_MASTER_DEV_EN)

//------------------------------------------------------------------------------
// Register 81 (0x51) SPI_MASTER_TX_DATA
#define SPI_MASTER_TX_DATA             0x51

// Register 81 Bit Definitions
#define BIT_SPI_DATA_TX_0                     0                                 // SPI Master Tx Data. Data to be sent from SPI Master. Trigger will be used to indicate when new data has been moved into the transfer buffer.
#define MASK_SPI_DATA_TX_0                    (0x1 << BIT_SPI_DATA_TX_0)
#define BIT_SPI_DATA_TX_1                     1                                 // SPI Master Tx Data. Data to be sent from SPI Master. Trigger will be used to indicate when new data has been moved into the transfer buffer.
#define MASK_SPI_DATA_TX_1                    (0x1 << BIT_SPI_DATA_TX_1)
#define BIT_SPI_DATA_TX_2                     2                                 // SPI Master Tx Data. Data to be sent from SPI Master. Trigger will be used to indicate when new data has been moved into the transfer buffer.
#define MASK_SPI_DATA_TX_2                    (0x1 << BIT_SPI_DATA_TX_2)
#define BIT_SPI_DATA_TX_3                     3                                 // SPI Master Tx Data. Data to be sent from SPI Master. Trigger will be used to indicate when new data has been moved into the transfer buffer.
#define MASK_SPI_DATA_TX_3                    (0x1 << BIT_SPI_DATA_TX_3)
#define BIT_SPI_DATA_TX_4                     4                                 // SPI Master Tx Data. Data to be sent from SPI Master. Trigger will be used to indicate when new data has been moved into the transfer buffer.
#define MASK_SPI_DATA_TX_4                    (0x1 << BIT_SPI_DATA_TX_4)
#define BIT_SPI_DATA_TX_5                     5                                 // SPI Master Tx Data. Data to be sent from SPI Master. Trigger will be used to indicate when new data has been moved into the transfer buffer.
#define MASK_SPI_DATA_TX_5                    (0x1 << BIT_SPI_DATA_TX_5)
#define BIT_SPI_DATA_TX_6                     6                                 // SPI Master Tx Data. Data to be sent from SPI Master. Trigger will be used to indicate when new data has been moved into the transfer buffer.
#define MASK_SPI_DATA_TX_6                    (0x1 << BIT_SPI_DATA_TX_6)
#define BIT_SPI_DATA_TX_7                     7                                 // SPI Master Tx Data. Data to be sent from SPI Master. Trigger will be used to indicate when new data has been moved into the transfer buffer.
#define MASK_SPI_DATA_TX_7                    (0x1 << BIT_SPI_DATA_TX_7)
#define MASK_SPI_DATA_TX                      (0xFF << BIT_SPI_DATA_TX_0)

//------------------------------------------------------------------------------
// Register 82 (0x52) SPI_MASTER_RX_DATA
#define SPI_MASTER_RX_DATA             0x52

// Register 82 Bit Definitions
#define BIT_SPI_DATA_RX_0                     0                                 // SPI Master Rx Data. Data received from slave. This register also contains the status bytes when operating in full duplex mode. Trigger will be used to indicate when data has been read out of the register.
#define MASK_SPI_DATA_RX_0                    (0x1 << BIT_SPI_DATA_RX_0)
#define BIT_SPI_DATA_RX_1                     1                                 // SPI Master Rx Data. Data received from slave. This register also contains the status bytes when operating in full duplex mode. Trigger will be used to indicate when data has been read out of the register.
#define MASK_SPI_DATA_RX_1                    (0x1 << BIT_SPI_DATA_RX_1)
#define BIT_SPI_DATA_RX_2                     2                                 // SPI Master Rx Data. Data received from slave. This register also contains the status bytes when operating in full duplex mode. Trigger will be used to indicate when data has been read out of the register.
#define MASK_SPI_DATA_RX_2                    (0x1 << BIT_SPI_DATA_RX_2)
#define BIT_SPI_DATA_RX_3                     3                                 // SPI Master Rx Data. Data received from slave. This register also contains the status bytes when operating in full duplex mode. Trigger will be used to indicate when data has been read out of the register.
#define MASK_SPI_DATA_RX_3                    (0x1 << BIT_SPI_DATA_RX_3)
#define BIT_SPI_DATA_RX_4                     4                                 // SPI Master Rx Data. Data received from slave. This register also contains the status bytes when operating in full duplex mode. Trigger will be used to indicate when data has been read out of the register.
#define MASK_SPI_DATA_RX_4                    (0x1 << BIT_SPI_DATA_RX_4)
#define BIT_SPI_DATA_RX_5                     5                                 // SPI Master Rx Data. Data received from slave. This register also contains the status bytes when operating in full duplex mode. Trigger will be used to indicate when data has been read out of the register.
#define MASK_SPI_DATA_RX_5                    (0x1 << BIT_SPI_DATA_RX_5)
#define BIT_SPI_DATA_RX_6                     6                                 // SPI Master Rx Data. Data received from slave. This register also contains the status bytes when operating in full duplex mode. Trigger will be used to indicate when data has been read out of the register.
#define MASK_SPI_DATA_RX_6                    (0x1 << BIT_SPI_DATA_RX_6)
#define BIT_SPI_DATA_RX_7                     7                                 // SPI Master Rx Data. Data received from slave. This register also contains the status bytes when operating in full duplex mode. Trigger will be used to indicate when data has been read out of the register.
#define MASK_SPI_DATA_RX_7                    (0x1 << BIT_SPI_DATA_RX_7)
#define MASK_SPI_DATA_RX                      (0xFF << BIT_SPI_DATA_RX_0)

//------------------------------------------------------------------------------
// Register 83 (0x53) SPI_MASTER_IEN
#define SPI_MASTER_IEN                 0x53

// Register 83 Bit Definitions
#define BIT_SPI_HOLD_TXE_IEN                  0                                 // Interrupt enable for spi_hold_txe_int.
#define MASK_SPI_HOLD_TXE_IEN                 (0x1 << BIT_SPI_HOLD_TXE_IEN)
#define BIT_SPI_TX_DONE_IEN                   1                                 // Interrupt enable for spi_tx_done.
#define MASK_SPI_TX_DONE_IEN                  (0x1 << BIT_SPI_TX_DONE_IEN)
#define BIT_SPI_TX_OE_IEN                     2                                 // Interrupt enable for spi_tx_oe.
#define MASK_SPI_TX_OE_IEN                    (0x1 << BIT_SPI_TX_OE_IEN)
#define BIT_SPI_RX_FULL_IEN                   3                                 // Interrupt enable for spi_rx_full_int.
#define MASK_SPI_RX_FULL_IEN                  (0x1 << BIT_SPI_RX_FULL_IEN)
#define BIT_SPI_RX_OE_IEN                     4                                 // Interrupt enable for spi_rx_oe.
#define MASK_SPI_RX_OE_IEN                    (0x1 << BIT_SPI_RX_OE_IEN)
#define BIT_SPI_TRANSFER_SIZE_DONE_IEN        5                                 // Interrupt enable for spi_transfer_size_done.
#define MASK_SPI_TRANSFER_SIZE_DONE_IEN       (0x1 << BIT_SPI_TRANSFER_SIZE_DONE_IEN)

//------------------------------------------------------------------------------
// Register 84 (0x54) SPI_MASTER_INT
#define SPI_MASTER_INT                     0x54

// Register 84 Bit Definitions
#define BIT_SPI_HOLD_TXE_INT                  0                                 // Tx holding register interrupt bit. Indicates that the holding register has become empty.
#define MASK_SPI_HOLD_TXE_INT                 (0x1 << BIT_SPI_HOLD_TXE_INT)
#define BIT_SPI_TX_DONE_INT                   1                                 // Tx state machine done interrupt bit. Set when the state machine moves from busy to idle, i.e. at the end of an spi data transfer.
#define MASK_SPI_TX_DONE_INT                  (0x1 << BIT_SPI_TX_DONE_INT)
#define BIT_SPI_TX_OE_INT                     2                                 // Tx overrun error. Set to 1 when data is written to spi_data_tx while the register is still full. If this occurs the new data overwrites the old.
#define MASK_SPI_TX_OE_INT                    (0x1 << BIT_SPI_TX_OE_INT)
#define BIT_SPI_RX_FULL_INT                   3                                 // Rx data register interrupt bit. When high it indicates that spi_data_rx has new data to be read out.
#define MASK_SPI_RX_FULL_INT                  (0x1 << BIT_SPI_RX_FULL_INT)
#define BIT_SPI_RX_OE_INT                     4                                 // Rx overrun error. Set to 1 when data is received and spi_data_rx is still full. If this occurs the new data is ignored.
#define MASK_SPI_RX_OE_INT                    (0x1 << BIT_SPI_RX_OE_INT)
#define BIT_SPI_TRANSFER_SIZE_DONE            5                                 // Transfer Size Done. Set to 1 when the requested transfer size has been completed.
#define MASK_SPI_TRANSFER_SIZE_DONE           (0x1 << BIT_SPI_TRANSFER_SIZE_DONE)

//------------------------------------------------------------------------------
// Register 85 (0x55) SPI_MASTER_SETUP
#define SPI_MASTER_SETUP                    0x55

// Register 85 Bit Definitions
#define BIT_CPHA                              0                                 // SPI Clock Phase Bit - selects the format of the SPI clk. A change of this bit aborts a transmission in progress and returns the SPI system into idle state. 0 - data is latched from SDI on the SPI clk leading edge and loaded onto SDO on the SPI clk trailing edge. 1 - data is latched from SDI on the SPI clk trailing edge and loaded onto SDO on the SPI clk leading edge.
#define MASK_CPHA                             (0x1 << BIT_CPHA)
#define BIT_CPOL                              1                                 // SPI Clock Polarity Bit - selects the polarity of the SPI clk. When transmitting data between SPI modules, both modules must be using the same CPOL values. A change of this bit aborts a transmission in progress and returns the SPI system into idle state. 0 - Active high clk, SCK low in idle. 1 - Active high clk, SCK high in idle.
#define MASK_CPOL                             (0x1 << BIT_CPOL)
#define BIT_LSBFIRST                          2                                 // When 1, data is transferred LSB first. When 0, data is transferred MSB first. This does not affect the order in which data is stored in the rx and tx registers, simply the order in which data is transmitted and received.
#define MASK_LSBFIRST                         (0x1 << BIT_LSBFIRST)
#define BIT_SPI_SS_N                          3                                 // SPI Slave Select. Used when a CPU wishes to control the ss_n. Write '0' to set spi_ss_n active, '1' to set it inactive. When this is de-asserted CPOL bit should NOT be toggled at the same time. Should NOT be used in conjunction with SPI Transfer Size.
#define MASK_SPI_SS_N                         (0x1 << BIT_SPI_SS_N)

//------------------------------------------------------------------------------
// Register 86 (0x56) SPI_MASTER_CLK_DIV
#define SPI_MASTER_CLK_DIV           0x56

// Register 86 Bit Definitions
#define BIT_SPI_CLK_DIV_0_0                   0                                 // Lower 8 bits of clock divider register to determine the frequency of the SPI clk. Trigger will be used to synchronise the divide counter to the new frequency.
#define MASK_SPI_CLK_DIV_0_0                  (0x1 << BIT_SPI_CLK_DIV_0_0)
#define BIT_SPI_CLK_DIV_0_1                   1                                 // Lower 8 bits of clock divider register to determine the frequency of the SPI clk. Trigger will be used to synchronise the divide counter to the new frequency.
#define MASK_SPI_CLK_DIV_0_1                  (0x1 << BIT_SPI_CLK_DIV_0_1)
#define BIT_SPI_CLK_DIV_0_2                   2                                 // Lower 8 bits of clock divider register to determine the frequency of the SPI clk. Trigger will be used to synchronise the divide counter to the new frequency.
#define MASK_SPI_CLK_DIV_0_2                  (0x1 << BIT_SPI_CLK_DIV_0_2)
#define BIT_SPI_CLK_DIV_0_3                   3                                 // Lower 8 bits of clock divider register to determine the frequency of the SPI clk. Trigger will be used to synchronise the divide counter to the new frequency.
#define MASK_SPI_CLK_DIV_0_3                  (0x1 << BIT_SPI_CLK_DIV_0_3)
#define BIT_SPI_CLK_DIV_0_4                   4                                 // Lower 8 bits of clock divider register to determine the frequency of the SPI clk. Trigger will be used to synchronise the divide counter to the new frequency.
#define MASK_SPI_CLK_DIV_0_4                  (0x1 << BIT_SPI_CLK_DIV_0_4)
#define BIT_SPI_CLK_DIV_0_5                   5                                 // Lower 8 bits of clock divider register to determine the frequency of the SPI clk. Trigger will be used to synchronise the divide counter to the new frequency.
#define MASK_SPI_CLK_DIV_0_5                  (0x1 << BIT_SPI_CLK_DIV_0_5)
#define BIT_SPI_CLK_DIV_0_6                   6                                 // Lower 8 bits of clock divider register to determine the frequency of the SPI clk. Trigger will be used to synchronise the divide counter to the new frequency.
#define MASK_SPI_CLK_DIV_0_6                  (0x1 << BIT_SPI_CLK_DIV_0_6)
#define BIT_SPI_CLK_DIV_0_7                   7                                 // Lower 8 bits of clock divider register to determine the frequency of the SPI clk. Trigger will be used to synchronise the divide counter to the new frequency.
#define MASK_SPI_CLK_DIV_0_7                  (0x1 << BIT_SPI_CLK_DIV_0_7)
#define MASK_SPI_CLK_DIV_0                    (0xFF << BIT_SPI_CLK_DIV_0_0)

//------------------------------------------------------------------------------
// Register 87 (0x57) SPI_MASTER_DATA_DELAY
#define SPI_MASTER_DATA_DELAY          0x57

// Register 87 Bit Definitions
#define BIT_SPI_DATA_DELAY_0                  0                                 // Inserts a fixed delay between ss_n going active and the first SCK cycle. It is recommended that this value is non-zero when using the Transfer Size feature.
#define MASK_SPI_DATA_DELAY_0                 (0x1 << BIT_SPI_DATA_DELAY_0)
#define BIT_SPI_DATA_DELAY_1                  1                                 // Inserts a fixed delay between ss_n going active and the first SCK cycle. It is recommended that this value is non-zero when using the Transfer Size feature.
#define MASK_SPI_DATA_DELAY_1                 (0x1 << BIT_SPI_DATA_DELAY_1)
#define BIT_SPI_DATA_DELAY_2                  2                                 // Inserts a fixed delay between ss_n going active and the first SCK cycle. It is recommended that this value is non-zero when using the Transfer Size feature.
#define MASK_SPI_DATA_DELAY_2                 (0x1 << BIT_SPI_DATA_DELAY_2)
#define BIT_SPI_DATA_DELAY_3                  3                                 // Inserts a fixed delay between ss_n going active and the first SCK cycle. It is recommended that this value is non-zero when using the Transfer Size feature.
#define MASK_SPI_DATA_DELAY_3                 (0x1 << BIT_SPI_DATA_DELAY_3)
#define BIT_SPI_DATA_DELAY_4                  4                                 // Inserts a fixed delay between ss_n going active and the first SCK cycle. It is recommended that this value is non-zero when using the Transfer Size feature.
#define MASK_SPI_DATA_DELAY_4                 (0x1 << BIT_SPI_DATA_DELAY_4)
#define BIT_SPI_DATA_DELAY_5                  5                                 // Inserts a fixed delay between ss_n going active and the first SCK cycle. It is recommended that this value is non-zero when using the Transfer Size feature.
#define MASK_SPI_DATA_DELAY_5                 (0x1 << BIT_SPI_DATA_DELAY_5)
#define BIT_SPI_DATA_DELAY_6                  6                                 // Inserts a fixed delay between ss_n going active and the first SCK cycle. It is recommended that this value is non-zero when using the Transfer Size feature.
#define MASK_SPI_DATA_DELAY_6                 (0x1 << BIT_SPI_DATA_DELAY_6)
#define BIT_SPI_DATA_DELAY_7                  7                                 // Inserts a fixed delay between ss_n going active and the first SCK cycle. It is recommended that this value is non-zero when using the Transfer Size feature.
#define MASK_SPI_DATA_DELAY_7                 (0x1 << BIT_SPI_DATA_DELAY_7)
#define MASK_SPI_DATA_DELAY                   (0xFF << BIT_SPI_DATA_DELAY_0)

//------------------------------------------------------------------------------
// Register 88 (0x58) SPI_MASTER_SS_SETUP
#define SPI_MASTER_SS_SETUP                 0x58

// Register 88 Bit Definitions
#define BIT_SPI_SS_IDLE_STATE                 0                                 // SPI Slave Select Idle State. '1' is an idle state of high, therefore ss_n is acive low. '0' is an idle state of low, therefore ss_n is active high
#define MASK_SPI_SS_IDLE_STATE                (0x1 << BIT_SPI_SS_IDLE_STATE)
#define BIT_SPI_SS_ROUTE_0                    1                                 // SPI Slave Select Route. Sets the active slave select out of 4 different slave selects.
#define MASK_SPI_SS_ROUTE_0                   (0x1 << BIT_SPI_SS_ROUTE_0)
#define BIT_SPI_SS_ROUTE_1                    2                                 // SPI Slave Select Route. Sets the active slave select out of 4 different slave selects.
#define MASK_SPI_SS_ROUTE_1                   (0x1 << BIT_SPI_SS_ROUTE_1)
#define MASK_SPI_SS_ROUTE                     (0x3 << BIT_SPI_SS_ROUTE_0)

//------------------------------------------------------------------------------
// Register 89 (0x59) SPI_MASTER_TRANSFER_SIZE_L
#define SPI_MASTER_TRANSFER_SIZE_L    0x59

// Register 89 Bit Definitions
#define BIT_SPI_TRANSFER_SIZE_L_0            0                                 // Lower 8 bits of transfer size register. Allows the hardware to auto-control the assertion and de-assertion of slave select. Set the lower first and then the upper byte. Setting both bytes to 0 will abort the transfer.
#define MASK_SPI_TRANSFER_SIZE_L_0           (0x1 << BIT_SPI_TRANSFER_SIZE_L_0)
#define BIT_SPI_TRANSFER_SIZE_L_1            1                                 // Lower 8 bits of transfer size register. Allows the hardware to auto-control the assertion and de-assertion of slave select. Set the lower first and then the upper byte. Setting both bytes to 0 will abort the transfer.
#define MASK_SPI_TRANSFER_SIZE_L_1           (0x1 << BIT_SPI_TRANSFER_SIZE_L_1)
#define BIT_SPI_TRANSFER_SIZE_L_2            2                                 // Lower 8 bits of transfer size register. Allows the hardware to auto-control the assertion and de-assertion of slave select. Set the lower first and then the upper byte. Setting both bytes to 0 will abort the transfer.
#define MASK_SPI_TRANSFER_SIZE_L_2           (0x1 << BIT_SPI_TRANSFER_SIZE_L_2)
#define BIT_SPI_TRANSFER_SIZE_L_3            3                                 // Lower 8 bits of transfer size register. Allows the hardware to auto-control the assertion and de-assertion of slave select. Set the lower first and then the upper byte. Setting both bytes to 0 will abort the transfer.
#define MASK_SPI_TRANSFER_SIZE_L_3           (0x1 << BIT_SPI_TRANSFER_SIZE_L_3)
#define BIT_SPI_TRANSFER_SIZE_L_4            4                                 // Lower 8 bits of transfer size register. Allows the hardware to auto-control the assertion and de-assertion of slave select. Set the lower first and then the upper byte. Setting both bytes to 0 will abort the transfer.
#define MASK_SPI_TRANSFER_SIZE_L_4           (0x1 << BIT_SPI_TRANSFER_SIZE_L_4)
#define BIT_SPI_TRANSFER_SIZE_L_5            5                                 // Lower 8 bits of transfer size register. Allows the hardware to auto-control the assertion and de-assertion of slave select. Set the lower first and then the upper byte. Setting both bytes to 0 will abort the transfer.
#define MASK_SPI_TRANSFER_SIZE_L_5           (0x1 << BIT_SPI_TRANSFER_SIZE_L_5)
#define BIT_SPI_TRANSFER_SIZE_L_6            6                                 // Lower 8 bits of transfer size register. Allows the hardware to auto-control the assertion and de-assertion of slave select. Set the lower first and then the upper byte. Setting both bytes to 0 will abort the transfer.
#define MASK_SPI_TRANSFER_SIZE_L_6           (0x1 << BIT_SPI_TRANSFER_SIZE_L_6)
#define BIT_SPI_TRANSFER_SIZE_L_7            7                                 // Lower 8 bits of transfer size register. Allows the hardware to auto-control the assertion and de-assertion of slave select. Set the lower first and then the upper byte. Setting both bytes to 0 will abort the transfer.
#define MASK_SPI_TRANSFER_SIZE_L_7           (0x1 << BIT_SPI_TRANSFER_SIZE_L_7)
#define MASK_SPI_TRANSFER_SIZE_LO             (0xFF << BIT_SPI_TRANSFER_SIZE_L_0)

//------------------------------------------------------------------------------
// Register 90 (0x5A) SPI_MASTER_TRANSFER_SIZE_U
#define SPI_MASTER_TRANSFER_SIZE_U    0x5A

// Register 90 Bit Definitions
#define BIT_SPI_TRANSFER_SIZE_H_0            0                                 // Higher 8 bits of transfer size register.
#define MASK_SPI_TRANSFER_SIZE_H_0           (0x1 << BIT_SPI_TRANSFER_SIZE_H_0)
#define BIT_SPI_TRANSFER_SIZE_H_1            1                                 // Higher 8 bits of transfer size register.
#define MASK_SPI_TRANSFER_SIZE_H_1           (0x1 << BIT_SPI_TRANSFER_SIZE_H_1)
#define BIT_SPI_TRANSFER_SIZE_H_2            2                                 // Higher 8 bits of transfer size register.
#define MASK_SPI_TRANSFER_SIZE_H_2           (0x1 << BIT_SPI_TRANSFER_SIZE_H_2)
#define BIT_SPI_TRANSFER_SIZE_H_3            3                                 // Higher 8 bits of transfer size register.
#define MASK_SPI_TRANSFER_SIZE_H_3           (0x1 << BIT_SPI_TRANSFER_SIZE_H_3)
#define BIT_SPI_TRANSFER_SIZE_H_4            4                                 // Higher 8 bits of transfer size register.
#define MASK_SPI_TRANSFER_SIZE_H_4           (0x1 << BIT_SPI_TRANSFER_SIZE_H_4)
#define BIT_SPI_TRANSFER_SIZE_H_5            5                                 // Higher 8 bits of transfer size register.
#define MASK_SPI_TRANSFER_SIZE_H_5           (0x1 << BIT_SPI_TRANSFER_SIZE_H_5)
#define BIT_SPI_TRANSFER_SIZE_H_6            6                                 // Higher 8 bits of transfer size register.
#define MASK_SPI_TRANSFER_SIZE_H_6           (0x1 << BIT_SPI_TRANSFER_SIZE_H_6)
#define BIT_SPI_TRANSFER_SIZE_H_7            7                                 // Higher 8 bits of transfer size register.
#define MASK_SPI_TRANSFER_SIZE_H_7           (0x1 << BIT_SPI_TRANSFER_SIZE_H_7)
#define MASK_SPI_TRANSFER_SIZE_HI             (0xFF << BIT_SPI_TRANSFER_SIZE_H_0)

//------------------------------------------------------------------------------
// Register 91 (0x5B) SPI_MASTER_TRANSFER_PENDING
#define SPI_MASTER_TRANSFER_PENDING    0x5B

// Register 91 Bit Definitions
#define BIT_SPI_TRANSFER_PENDING              0                                 // The live status of the SPI Master. Set to '1' when the SPI Master is busy servicing a prior request.
#define MASK_SPI_TRANSFER_PENDING             (0x1 << BIT_SPI_TRANSFER_PENDING)

#endif // __FT51_SPI_REGISTERS_H__
